@@ -35,6 +35,7 @@ import (
 
 	"gitlab.com/ubports/development/core/lomiri-push-service/bus"
 	"gitlab.com/ubports/development/core/lomiri-push-service/bus/networkmanager"
+	"gitlab.com/ubports/development/core/lomiri-push-service/bus/polld"
 	"gitlab.com/ubports/development/core/lomiri-push-service/bus/systemimage"
 	testibus "gitlab.com/ubports/development/core/lomiri-push-service/bus/testing"
 	"gitlab.com/ubports/development/core/lomiri-push-service/click"
@@ -1083,13 +1084,17 @@ func (cs *clientSuite) TestLoop(c *C) {
     Start() tests
 ******************************************************************/
 
+// Test for some key mocked DBus services required for integration testing.
 // XXX this is a hack.
 func (cs *clientSuite) hasDbus() bool {
-	for _, b := range []bus.Bus{bus.SystemBus, bus.SessionBus} {
-		if b.Endpoint(bus.BusDaemonAddress, cs.log).Dial() != nil {
-			return false
-		}
+	if bus.SystemBus.Endpoint(systemimage.BusAddress, cs.log).Dial() != nil {
+		return false
 	}
+
+	if bus.SessionBus.Endpoint(polld.BusAddress, cs.log).Dial() != nil {
+		return false
+	}
+
 	return true
 }
 
