@@ -363,13 +363,14 @@ func (ps *postalSuite) TestPostHappyPath(c *C) {
 func (ps *postalSuite) TestPostFailsIfBadArgs(c *C) {
 	for i, s := range []struct {
 		appID, payload string
-		errt error
+		errt           *dbus.Error
 	}{
-		{anAppId, "zoom", ErrBadJSON},
-		{"bar", "hello", click.ErrInvalidAppId},
+		{anAppId, "zoom", dbus.MakeFailedError(ErrBadJSON)},
+		{"bar", "hello", MakeDBusNoObjectErrorWithReason(
+			aPackageOnBus, click.ErrInvalidAppId)},
 	} {
 		err := new(PostalService).post(aMsg, s.appID, s.payload)
-		c.Check(err, Equals, s.errt, Commentf("iteration #%d", i))
+		c.Check(err, DeepEquals, s.errt, Commentf("iteration #%d", i))
 	}
 }
 
@@ -528,7 +529,8 @@ func (ps *postalSuite) TestNotificationsWorks(c *C) {
 func (ps *postalSuite) TestNotificationsFailsIfBadArgs(c *C) {
 	reg, err := new(PostalService).popAll(aMsg, "potato")
 	c.Check(reg, HasLen, 0)
-	c.Check(err, Equals, click.ErrInvalidAppId)
+	c.Check(err, DeepEquals, MakeDBusNoObjectErrorWithReason(
+		aPackageOnBus, click.ErrInvalidAppId))
 }
 
 func (ps *postalSuite) TestMessageHandlerPublicAPI(c *C) {
@@ -761,7 +763,8 @@ func (ps *postalSuite) TestListPersistent(c *C) {
 func (ps *postalSuite) TestListPersistentErrors(c *C) {
 	reg, err := new(PostalService).listPersistent(aMsg, "bar")
 	c.Check(reg, IsNil)
-	c.Check(err, Equals, click.ErrInvalidAppId)
+	c.Check(err, DeepEquals, MakeDBusNoObjectErrorWithReason(
+		aPackageOnBus, click.ErrInvalidAppId))
 }
 
 func (ps *postalSuite) TestClearPersistent(c *C) {
@@ -776,7 +779,8 @@ func (ps *postalSuite) TestClearPersistent(c *C) {
 
 func (ps *postalSuite) TestClearPersistentErrors(c *C) {
 	_, err := new(PostalService).clearPersistent(aMsg, "xyzzy", []string{})
-	c.Check(err, Equals, click.ErrInvalidAppId)
+	c.Check(err, DeepEquals, MakeDBusNoObjectErrorWithReason(
+		aPackageOnBus, click.ErrInvalidAppId))
 }
 
 func (ps *postalSuite) TestSetCounter(c *C) {
@@ -805,13 +809,14 @@ func (ps *postalSuite) TestSetCounterErrors(c *C) {
 		id      string
 		count   int
 		visible bool
-		err     error
+		err     *dbus.Error
 	}{
 		{anAppId, 42, true, nil}, // for reference
-		{"xyzzy", 42, true, click.ErrInvalidAppId},
+		{"xyzzy", 42, true, MakeDBusNoObjectErrorWithReason(
+			aPackageOnBus, click.ErrInvalidAppId)},
 	} {
 		err := svc.setCounter(aMsg, s.id, s.count, s.visible)
-		c.Check(err, Equals, s.err, Commentf("iter %d", i))
+		c.Check(err, DeepEquals, s.err, Commentf("iter %d", i))
 	}
 }
 
